% Quokka3 settingsfile for a 1cm x 1cm Si-perovskite tandem cell
%
% defines a "L-shaped" metallization layout using the generic syntax
% includes a 2mm non-illuminated perimeter
% based on a Fraunhofer ISE tandem cell design
% details see A. Fell et al., JPV (2022), in review
%
% (c) 2022 Andreas Fell

Syntax = 'generic';


Solver.SolutionType = 'light JV-curve';
% Solver.SolutionType = 'single JV-point';
% Solver.SingleJVPoint.Type = 'MPP';
Solver.Electrical.MetalModelType = 'finite-differences';
Solver.Electrical.BulkModelType = 'equivalent-circuit'; % 'equivalent-circuit' recommended for tandem simulations; since version 2.3.5 accounts also for minority carrier lateral transport in bulk (i.e. in main subcell = Si bottom cell) and results in correct edge losses
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 298.15;

Domain.Dimensions = 3;
Domain.DeviceType = 'semiconductor device';
% you can set below solution domain size to e.g. 5.01mm x 5.01mm in order to still include a bit of the busbar but simulate an (almost) perimeter-loss-free cell
Domain.Wx = 7 mm;
Domain.Wy = 7 mm;
Domain.Wz = 250 um;

Thermal.T = 298.15;

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.FrontIllumination.Shape = 'rectangle'; % 1 cm x 1cm illumination defines active cell area
Optical.FrontIllumination.PositionX = 0 cm;
Optical.FrontIllumination.SizeX = 1 cm;
Optical.FrontIllumination.PositionY = 0 cm;
Optical.FrontIllumination.SizeY = 1 cm;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file'; % Text is the top cell transmission to the bottom cell
Optical.TextZ.FrontText.Text.File = 'tandem_Text.csv';
Optical.TextZ.FrontText.Aext.Type = 'file'; % Aext is the parasitic absorption in the top cell materials during the first pass of light
Optical.TextZ.FrontText.Aext.File = 'tandem_Aext.csv';
Optical.TextZ.FrontText.Agen.Type = 'file'; % Agen is the active absorption in the top cell, i.e. the top cell EQE
Optical.TextZ.FrontText.Agen.File = 'tandem_APero.csv';
Optical.TextZ.FrontText.FacetAngle = 0;
Optical.TextZ.FrontZ.Type = 'parameterization'; % below parameterization is a best-fit to the ray tracing results
Optical.TextZ.FrontZ.Z0 = 20.51;
Optical.TextZ.FrontZ.Zinf = 1.201;
Optical.TextZ.FrontZ.Zp = 2.55;
Optical.ScaleGeneration = 1;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 1.5;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 3000;
Bulk.Electrical.Recombination.SRH(1).taup = 3000;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;

% front side skins including top cells via a lumped-subcell skin layer
SkinFeature(1).Name = 'floating top cell';
SkinFeature(1).Geometry.Plane = 'front';
SkinFeature(1).Geometry.Shape = 'full';
SkinFeature(1).ElectricalModelType = 'lumped';
SkinFeature(1).Lumped.Electrical.RsheetEnable = 1;
SkinFeature(1).Lumped.Electrical.Rsheet = 150;
SkinFeature(1).Lumped.Electrical.ConductionType = 'n-type';
SkinFeature(1).Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
SkinFeature(1).Lumped.Electrical.NonContactedRecombination.J0 = 10 fA/cm2;
SkinFeature(1).Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
SkinFeature(1).Lumped.Electrical.ContactedRecombination.J0 = 10 fA/cm2;
SkinFeature(1).Layer(1).Name = 'Si-emitter';
SkinFeature(1).Layer(1).Type = 'transport';
SkinFeature(1).Layer(1).Thickness = 10; % does not have any influence, but needs to be set
SkinFeature(1).Layer(1).RsheetType = 'user';
SkinFeature(1).Layer(1).Rsheet = 1e4;
SkinFeature(1).Layer(1).ConductionType = 'n-type';
SkinFeature(1).Layer(2).Name = 'rec-TCO';
SkinFeature(1).Layer(2).Type = 'transport';
SkinFeature(1).Layer(2).Thickness = 10; % does not have any influence, but needs to be set
SkinFeature(1).Layer(2).RsheetType = 'user';
SkinFeature(1).Layer(2).Rsheet = 1e4;
SkinFeature(1).Layer(2).ConductionType = 'p-type';
SkinFeature(1).Layer(2).JunctionResistivity.OhmicResistivity = 5e2; % high junction resistance represents isolation of subcells in perimeter; too high value results in convergence issues towards Jsc
SkinFeature(1).Layer(3).Name = 'TopCell';
SkinFeature(1).Layer(3).Type = 'lumped-subcell';
SkinFeature(1).Layer(3).Subcell.JVType = 'two-diode';
SkinFeature(1).Layer(3).Subcell.J01 = 4e-21 A/cm2;
SkinFeature(1).Layer(3).Subcell.J02 = 5e-12 A/cm2;
SkinFeature(1).Layer(3).Subcell.Rseries = 2.5;
SkinFeature(1).Layer(3).Subcell.Rshunt = 1e10;

SkinFeature(2).Name = 'active top cell';
SkinFeature(2).Geometry.Plane = 'front';
SkinFeature(2).Geometry.Shape = 'rectangle';
SkinFeature(2).Geometry.PositionX = 0 cm;
SkinFeature(2).Geometry.SizeX = 1 cm;
SkinFeature(2).Geometry.PositionY = 0 cm;
SkinFeature(2).Geometry.SizeY = 1 cm;
SkinFeature(2).ElectricalModelType = 'lumped';
SkinFeature(2).Lumped.Electrical.RsheetEnable = 1;
SkinFeature(2).Lumped.Electrical.Rsheet = 150;
SkinFeature(2).Lumped.Electrical.ConductionType = 'n-type';
SkinFeature(2).Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
SkinFeature(2).Lumped.Electrical.NonContactedRecombination.J0 = 10 fA/cm2;
SkinFeature(2).Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
SkinFeature(2).Lumped.Electrical.ContactedRecombination.J0 = 10 fA/cm2;
SkinFeature(2).Layer(1).Name = 'Si-emitter';
SkinFeature(2).Layer(1).Type = 'transport';
SkinFeature(2).Layer(1).Thickness = 10; % does not have any influence, but needs to be set
SkinFeature(2).Layer(1).RsheetType = 'user';
SkinFeature(2).Layer(1).Rsheet = 1e4;
SkinFeature(2).Layer(1).ConductionType = 'n-type';
SkinFeature(2).Layer(2).Name = 'rec-TCO';
SkinFeature(2).Layer(2).Type = 'transport';
SkinFeature(2).Layer(2).Thickness = 10; % does not have any influence, but needs to be set
SkinFeature(2).Layer(2).RsheetType = 'user';
SkinFeature(2).Layer(2).Rsheet = 1e4;
SkinFeature(2).Layer(2).ConductionType = 'p-type';
SkinFeature(2).Layer(2).JunctionResistivity.OhmicResistivity = 1e-6; % well connected subcells
SkinFeature(2).Layer(3).Name = 'TopCell';
SkinFeature(2).Layer(3).Type = 'lumped-subcell';
SkinFeature(2).Layer(3).Subcell.JVType = 'two-diode';
SkinFeature(2).Layer(3).Subcell.J01 = 4e-21 A/cm2;
SkinFeature(2).Layer(3).Subcell.J02 = 5e-12 A/cm2;
SkinFeature(2).Layer(3).Subcell.Rseries = 2.5;
SkinFeature(2).Layer(3).Subcell.Rshunt = 1e10;

% rear side skin

SkinFeature(10).Name = 'rear skin';
SkinFeature(10).Geometry.Plane = 'rear';
SkinFeature(10).Geometry.Shape = 'full';
SkinFeature(10).ElectricalModelType = 'lumped';
SkinFeature(10).Lumped.Electrical.RsheetEnable = 1;
SkinFeature(10).Lumped.Electrical.Rsheet = 100;
SkinFeature(10).Lumped.Electrical.ConductionType = 'p-type';
SkinFeature(10).Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
SkinFeature(10).Lumped.Electrical.ContactedRecombination.J0 = 20 fA/cm2;

% front side L-shaped contact openings and metallization

ContactFeature(1).Name = 'front contact opening';
ContactFeature(1).Geometry.Plane = 'front';
ContactFeature(1).Geometry.Shape = 'rectangle';
ContactFeature(1).Geometry.PositionX = 2806.25;
ContactFeature(1).Geometry.PositionY = 625;
ContactFeature(1).Geometry.SizeX = 4387.5;
ContactFeature(1).Geometry.SizeY = 25;
ContactFeature(1).OhmicResistivity = 1e-3;
MetalFeature(1).Name = 'front finger';
MetalFeature(1).Geometry.Plane = 'front';
MetalFeature(1).Geometry.Shape = 'rectangle';
MetalFeature(1).Geometry.PositionX = 2806.25;
MetalFeature(1).Geometry.PositionY = 625;
MetalFeature(1).Geometry.SizeX = 4387.5;
MetalFeature(1).Geometry.SizeY = 25;
MetalFeature(1).Electrical.Polarity = 'n-type';
MetalFeature(1).Electrical.Rsheet = 0.053;
MetalFeature(1).Optical.ShadingFraction = 1;
ContactFeature(2).Name = 'front contact opening';
ContactFeature(2).Geometry.Plane = 'front';
ContactFeature(2).Geometry.Shape = 'rectangle';
ContactFeature(2).Geometry.PositionX = 625;
ContactFeature(2).Geometry.PositionY = 2806.25;
ContactFeature(2).Geometry.SizeX = 25;
ContactFeature(2).Geometry.SizeY = 4387.5;
ContactFeature(2).OhmicResistivity = 1e-3;
MetalFeature(2).Name = 'front finger';
MetalFeature(2).Geometry.Plane = 'front';
MetalFeature(2).Geometry.Shape = 'rectangle';
MetalFeature(2).Geometry.PositionX = 625;
MetalFeature(2).Geometry.PositionY = 2806.25;
MetalFeature(2).Geometry.SizeX = 25;
MetalFeature(2).Geometry.SizeY = 4387.5;
MetalFeature(2).Electrical.Polarity = 'n-type';
MetalFeature(2).Electrical.Rsheet = 0.053;
MetalFeature(2).Optical.ShadingFraction = 1;
ContactFeature(3).Name = 'front contact opening';
ContactFeature(3).Geometry.Plane = 'front';
ContactFeature(3).Geometry.Shape = 'rectangle';
ContactFeature(3).Geometry.PositionX = 3431.25;
ContactFeature(3).Geometry.PositionY = 1875;
ContactFeature(3).Geometry.SizeX = 3137.5;
ContactFeature(3).Geometry.SizeY = 25;
ContactFeature(3).OhmicResistivity = 1e-3;
MetalFeature(3).Name = 'front finger';
MetalFeature(3).Geometry.Plane = 'front';
MetalFeature(3).Geometry.Shape = 'rectangle';
MetalFeature(3).Geometry.PositionX = 3431.25;
MetalFeature(3).Geometry.PositionY = 1875;
MetalFeature(3).Geometry.SizeX = 3137.5;
MetalFeature(3).Geometry.SizeY = 25;
MetalFeature(3).Electrical.Polarity = 'n-type';
MetalFeature(3).Electrical.Rsheet = 0.053;
MetalFeature(3).Optical.ShadingFraction = 1;
ContactFeature(4).Name = 'front contact opening';
ContactFeature(4).Geometry.Plane = 'front';
ContactFeature(4).Geometry.Shape = 'rectangle';
ContactFeature(4).Geometry.PositionX = 1875;
ContactFeature(4).Geometry.PositionY = 3431.25;
ContactFeature(4).Geometry.SizeX = 25;
ContactFeature(4).Geometry.SizeY = 3137.5;
ContactFeature(4).OhmicResistivity = 1e-3;
MetalFeature(4).Name = 'front finger';
MetalFeature(4).Geometry.Plane = 'front';
MetalFeature(4).Geometry.Shape = 'rectangle';
MetalFeature(4).Geometry.PositionX = 1875;
MetalFeature(4).Geometry.PositionY = 3431.25;
MetalFeature(4).Geometry.SizeX = 25;
MetalFeature(4).Geometry.SizeY = 3137.5;
MetalFeature(4).Electrical.Polarity = 'n-type';
MetalFeature(4).Electrical.Rsheet = 0.053;
MetalFeature(4).Optical.ShadingFraction = 1;
ContactFeature(5).Name = 'front contact opening';
ContactFeature(5).Geometry.Plane = 'front';
ContactFeature(5).Geometry.Shape = 'rectangle';
ContactFeature(5).Geometry.PositionX = 4056.25;
ContactFeature(5).Geometry.PositionY = 3125;
ContactFeature(5).Geometry.SizeX = 1887.5;
ContactFeature(5).Geometry.SizeY = 25;
ContactFeature(5).OhmicResistivity = 1e-3;
MetalFeature(5).Name = 'front finger';
MetalFeature(5).Geometry.Plane = 'front';
MetalFeature(5).Geometry.Shape = 'rectangle';
MetalFeature(5).Geometry.PositionX = 4056.25;
MetalFeature(5).Geometry.PositionY = 3125;
MetalFeature(5).Geometry.SizeX = 1887.5;
MetalFeature(5).Geometry.SizeY = 25;
MetalFeature(5).Electrical.Polarity = 'n-type';
MetalFeature(5).Electrical.Rsheet = 0.053;
MetalFeature(5).Optical.ShadingFraction = 1;
ContactFeature(6).Name = 'front contact opening';
ContactFeature(6).Geometry.Plane = 'front';
ContactFeature(6).Geometry.Shape = 'rectangle';
ContactFeature(6).Geometry.PositionX = 3125;
ContactFeature(6).Geometry.PositionY = 4056.25;
ContactFeature(6).Geometry.SizeX = 25;
ContactFeature(6).Geometry.SizeY = 1887.5;
ContactFeature(6).OhmicResistivity = 1e-3;
MetalFeature(6).Name = 'front finger';
MetalFeature(6).Geometry.Plane = 'front';
MetalFeature(6).Geometry.Shape = 'rectangle';
MetalFeature(6).Geometry.PositionX = 3125;
MetalFeature(6).Geometry.PositionY = 4056.25;
MetalFeature(6).Geometry.SizeX = 25;
MetalFeature(6).Geometry.SizeY = 1887.5;
MetalFeature(6).Electrical.Polarity = 'n-type';
MetalFeature(6).Electrical.Rsheet = 0.053;
MetalFeature(6).Optical.ShadingFraction = 1;
ContactFeature(7).Name = 'front contact opening';
ContactFeature(7).Geometry.Plane = 'front';
ContactFeature(7).Geometry.Shape = 'rectangle';
ContactFeature(7).Geometry.PositionX = 4681.25;
ContactFeature(7).Geometry.PositionY = 4375;
ContactFeature(7).Geometry.SizeX = 637.5;
ContactFeature(7).Geometry.SizeY = 25;
ContactFeature(7).OhmicResistivity = 1e-3;
MetalFeature(7).Name = 'front finger';
MetalFeature(7).Geometry.Plane = 'front';
MetalFeature(7).Geometry.Shape = 'rectangle';
MetalFeature(7).Geometry.PositionX = 4681.25;
MetalFeature(7).Geometry.PositionY = 4375;
MetalFeature(7).Geometry.SizeX = 637.5;
MetalFeature(7).Geometry.SizeY = 25;
MetalFeature(7).Electrical.Polarity = 'n-type';
MetalFeature(7).Electrical.Rsheet = 0.053;
MetalFeature(7).Optical.ShadingFraction = 1;
ContactFeature(8).Name = 'front contact opening';
ContactFeature(8).Geometry.Plane = 'front';
ContactFeature(8).Geometry.Shape = 'rectangle';
ContactFeature(8).Geometry.PositionX = 4375;
ContactFeature(8).Geometry.PositionY = 4681.25;
ContactFeature(8).Geometry.SizeX = 25;
ContactFeature(8).Geometry.SizeY = 637.5;
ContactFeature(8).OhmicResistivity = 1e-3;
MetalFeature(8).Name = 'front finger';
MetalFeature(8).Geometry.Plane = 'front';
MetalFeature(8).Geometry.Shape = 'rectangle';
MetalFeature(8).Geometry.PositionX = 4375;
MetalFeature(8).Geometry.PositionY = 4681.25;
MetalFeature(8).Geometry.SizeX = 25;
MetalFeature(8).Geometry.SizeY = 637.5;
MetalFeature(8).Electrical.Polarity = 'n-type';
MetalFeature(8).Electrical.Rsheet = 0.053;
MetalFeature(8).Optical.ShadingFraction = 1;

% front side busbars outside active area

MetalFeature(19).Name = 'busbar 1';
MetalFeature(19).Geometry.Plane = 'front';
MetalFeature(19).Geometry.Shape = 'rectangle';
MetalFeature(19).Geometry.PositionX = 5.05 mm;
MetalFeature(19).Geometry.PositionY = 0;
MetalFeature(19).Geometry.SizeX = 0.1 mm;
MetalFeature(19).Geometry.SizeY = 10.2 mm;
MetalFeature(19).Electrical.Polarity = 'n-type';
MetalFeature(19).Electrical.Rsheet = 1e-3;
MetalFeature(19).Optical.ShadingFraction = 1;
MetalFeature(20).Name = 'busbar 2';
MetalFeature(20).Geometry.Plane = 'front';
MetalFeature(20).Geometry.Shape = 'rectangle';
MetalFeature(20).Geometry.PositionY = 5.05 mm;
MetalFeature(20).Geometry.PositionX = 0;
MetalFeature(20).Geometry.SizeY = 0.1 mm;
MetalFeature(20).Geometry.SizeX = 10.2 mm;
MetalFeature(20).Electrical.Polarity = 'n-type';
MetalFeature(20).Electrical.Rsheet = 1e-3;
MetalFeature(20).Optical.ShadingFraction = 1;
PadFeature(1).Name = 'busbar 1';
PadFeature(1).Geometry.Plane = 'front';
PadFeature(1).Geometry.Shape = 'rectangle';
PadFeature(1).Geometry.PositionX = 5.05 mm;
PadFeature(1).Geometry.PositionY = 0;
PadFeature(1).Geometry.SizeX = 0.1 mm;
PadFeature(1).Geometry.SizeY = 10.2 mm;
PadFeature(1).Electrical.Polarity = 'n-type';
PadFeature(1).Electrical.ContactResistivity = 1e-5;
PadFeature(2).Name = 'busbar 2';
PadFeature(2).Geometry.Plane = 'front';
PadFeature(2).Geometry.Shape = 'rectangle';
PadFeature(2).Geometry.PositionY = 5.05 mm;
PadFeature(2).Geometry.PositionX = 0;
PadFeature(2).Geometry.SizeY = 0.1 mm;
PadFeature(2).Geometry.SizeX = 10.2 mm;
PadFeature(2).Electrical.Polarity = 'n-type';
PadFeature(2).Electrical.ContactResistivity = 1e-5;

% rear side full area contact and metal

ContactFeature(19).Name = 'full area rear contact';
ContactFeature(19).Geometry.Plane = 'rear';
ContactFeature(19).Geometry.Shape = 'full';
ContactFeature(19).OhmicResistivity = 1e-3;
MetalFeature(21).Name = 'full area rear metal';
MetalFeature(21).Geometry.Plane = 'rear';
MetalFeature(21).Geometry.Shape = 'full';
MetalFeature(21).Electrical.Polarity = 'p-type';
MetalFeature(21).Electrical.Rsheet = 1e-3;
PadFeature(3).Name = 'full area rear pad';
PadFeature(3).Geometry.Plane = 'rear';
PadFeature(3).Geometry.Shape = 'full';
PadFeature(3).Electrical.Polarity = 'p-type';
PadFeature(3).Electrical.ContactResistivity = 1e-5;
